Eww
===

.. image:: https://travis-ci.org/py-eww/eww.svg?branch=master
    :target: https://travis-ci.org/py-eww/eww
.. image:: https://img.shields.io/coveralls/py-eww/eww.svg
    :target: https://coveralls.io/r/py-eww/eww
.. image:: https://readthedocs.org/projects/eww/badge/?version=latest
    :target: https://readthedocs.org/projects/eww/?badge=latest

|

Eww is an MIT-licensed Python library that gives you a REPL *inside* a running Python app.

Check out http://eww.io for more information.